==> pgmarket-1.2.0.tar.gz: pgmarket-1.2.0/shopping/product_details.php <==
<?
/* product_details.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");

/* if no product id is specified, go back to the main page */
/*
if (empty($id)) {
	header("Location: $CFG->wwwroot");
	die;
}
*/
if (empty($id)) {
	if (!empty($product_id)) {
		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
		if (db_num_rows($qid)) {
			list($id) = db_fetch_row($qid, 0);
		} else {
			header("Location: $CFG->wwwroot");
			die;
		}
	} else {
		header("Location: $CFG->wwwroot");
		die;
	}
}

$prod = load_product($product_id);
$DOC_TITLE = $prod ? $Product_Details . $prod->name : $Product_Not_Found;

include("$CFG->templatedir"."header.ihtml");
include("templates/product_details.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function load_product($product_id) {
/* load up the product details for a product with id $id and return it as
 * an object, or false if the object couldn't be loaded (ie. it's not found) */

	$qid = db_query("
	SELECT
		 p.id
		,p.name
		,p.brand_id
		,p.price
		,p.iva_id
		,p.discount
		,p.discqty
		,p.weight
		,p.on_special
		,p.description
		,p.extended_description
		,p.imagetype
		,p.imagewidth
		,p.imageheight
		,p.thumbwidth
		,p.thumbheight
		,pc.category_id
	FROM
		 products p
		,products_categories pc
	WHERE p.id = pc.product_id
		AND p.id = '$product_id'
	");

	if (db_num_rows($qid) > 0) {
		return db_fetch_object($qid, 0);
	} else {
		return false;
	}
}

?>

==> pgmarket-1.3.0.tar.gz: pgmarket-1.3.0/shopping/product_details.php <==
<?
/* product_details.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");

/* if no product id is specified, go back to the main page */
/*
if (empty($id)) {
	header("Location: $CFG->firstpage");
	die;
}
*/
if (empty($id)) {
	if (!empty($product_id)) {
		$qid = db_query("SELECT category_id FROM products_categories WHERE product_id = '$product_id'");
		if (db_num_rows($qid)) {
			list($id) = db_fetch_row($qid, 0);
		} else {
			header("Location: $CFG->firstpage");
			die;
		}
	} else {
		header("Location: $CFG->firstpage");
		die;
	}
}

$prod = load_product($product_id);
$DOC_TITLE = $prod ? $Product_Details . $prod->name : $Product_Not_Found;

include("$CFG->templatedir"."header.ihtml");
include("templates/product_details.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function load_product($product_id) {
/* load up the product details for a product with id $id and return it as
 * an object, or false if the object couldn't be loaded (ie. it's not found) */

	$qid = db_query("
	SELECT
		 p.id
		,p.name
		,p.brand_id
		,p.price
		,p.iva_id
		,p.discount
		,p.discqty
		,p.weight
		,p.on_special
		,p.description
		,p.extended_description
		,p.imagetype
		,p.imagewidth
		,p.imageheight
		,p.thumbwidth
		,p.thumbheight
		,pc.category_id
	FROM
		 products p
		,products_categories pc
	WHERE p.id = pc.product_id
		AND p.id = '$product_id'
	");

	if (db_num_rows($qid) > 0) {
		return db_fetch_object($qid, 0);
	} else {
		return false;
	}
}

?>
